@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,17 +54,127 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 /* Substitute the variable and function names.  */
-#define yyparse igraph_pajek_yyparse
-#define yylex   igraph_pajek_yylex
-#define yyerror igraph_pajek_yyerror
-#define yylval  igraph_pajek_yylval
-#define yychar  igraph_pajek_yychar
-#define yydebug igraph_pajek_yydebug
-#define yynerrs igraph_pajek_yynerrs
+#define yyparse         igraph_pajek_yyparse
+#define yylex           igraph_pajek_yylex
+#define yyerror         igraph_pajek_yyerror
+#define yylval          igraph_pajek_yylval
+#define yychar          igraph_pajek_yychar
+#define yydebug         igraph_pajek_yydebug
+#define yynerrs         igraph_pajek_yynerrs
+
+
+/* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
+#line 23 "foreign-pajek-parser.y"
+
+
+/* 
+   IGraph library.
+   Copyright (C) 2006  Gabor Csardi <csardi@rmki.kfki.hu>
+   MTA RMKI, Konkoly-Thege Miklos st. 29-33, Budapest 1121, Hungary
+   
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
+   
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+   
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc.,  51 Franklin Street, Fifth Floor, Boston, MA 
+   02110-1301 USA
+
+*/
+
+#include <stdio.h>
+#include <string.h>
+#include "types.h"
+#include "memory.h"
+#include "error.h"
+#include "attributes.h"
+#include "config.h"
+#include "igraph_math.h"
+#include <math.h>
+extern int igraph_pajek_yylex(void);
+extern int igraph_pajek_mylineno;
+extern char *igraph_pajek_yytext;
+extern int igraph_pajek_yyleng;
+char *igraph_i_pajek_errmsg;
+int igraph_pajek_yyerror(char *s);
+int igraph_i_pajek_add_string_vertex_attribute(const char *name, 
+					       const char *value,
+					       int len);
+int igraph_i_pajek_add_string_edge_attribute(const char *name, 
+					     const char *value,
+					     int len);
+int igraph_i_pajek_add_numeric_vertex_attribute(const char *name, 
+						igraph_real_t value);
+int igraph_i_pajek_add_numeric_edge_attribute(const char *name, 
+					      igraph_real_t value);
+int igraph_i_pajek_add_numeric_attribute(igraph_trie_t *names,
+					 igraph_vector_ptr_t *attrs,
+					 long int count,
+					 const char *attrname,
+					 igraph_integer_t vid,
+					 igraph_real_t number);
+int igraph_i_pajek_add_string_attribute(igraph_trie_t *names,
+					igraph_vector_ptr_t *attrs,
+					long int count,
+					const char *attrname,
+					igraph_integer_t vid,
+					const char *str);
+void igraph_i_pajek_reset_scanner(void);
+extern igraph_vector_t *igraph_pajek_vector;
+extern igraph_bool_t igraph_pajek_directed;
+extern long int igraph_pajek_vcount;
+extern int igraph_pajek_mode;
+extern long int igraph_pajek_actfrom, igraph_pajek_actto;
+extern igraph_trie_t *igraph_i_pajek_vertex_attribute_names;
+extern igraph_vector_t *igraph_i_pajek_vertex_attribute_types;
+extern igraph_vector_ptr_t *igraph_i_pajek_vertex_attributes;
+extern igraph_trie_t *igraph_i_pajek_edge_attribute_names;
+extern igraph_vector_t *igraph_i_pajek_edge_attribute_types;
+extern igraph_vector_ptr_t *igraph_i_pajek_edge_attributes;
+extern igraph_real_t igraph_pajek_get_number(const char *str, long int len);
+extern long int igraph_i_pajek_actvertex;
+extern long int igraph_i_pajek_actedge;
+
+
+/* Line 189 of yacc.c  */
+#line 160 "foreign-pajek-parser.c"
+
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 0
+#endif
+
+/* Enabling verbose error messages.  */
+#ifdef YYERROR_VERBOSE
+# undef YYERROR_VERBOSE
+# define YYERROR_VERBOSE 1
+#else
+# define YYERROR_VERBOSE 0
+#endif
+
+/* Enabling the token table.  */
+#ifndef YYTOKEN_TABLE
+# define YYTOKEN_TABLE 0
+#endif
 
 
 /* Tokens.  */
@@ -177,130 +286,36 @@
 
 
 
-/* Copy the first part of user declarations.  */
-#line 23 "foreign-pajek-parser.y"
-
-
-/* 
-   IGraph library.
-   Copyright (C) 2006  Gabor Csardi <csardi@rmki.kfki.hu>
-   MTA RMKI, Konkoly-Thege Miklos st. 29-33, Budapest 1121, Hungary
-   
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-   
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-   
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc.,  51 Franklin Street, Fifth Floor, Boston, MA 
-   02110-1301 USA
-
-*/
-
-#include <stdio.h>
-#include <string.h>
-#include "types.h"
-#include "memory.h"
-#include "error.h"
-#include "attributes.h"
-#include "config.h"
-#include "igraph_math.h"
-#include <math.h>
-extern int igraph_pajek_yylex(void);
-extern int igraph_pajek_mylineno;
-extern char *igraph_pajek_yytext;
-extern int igraph_pajek_yyleng;
-char *igraph_i_pajek_errmsg;
-int igraph_pajek_yyerror(char *s);
-int igraph_i_pajek_add_string_vertex_attribute(const char *name, 
-					       const char *value,
-					       int len);
-int igraph_i_pajek_add_string_edge_attribute(const char *name, 
-					     const char *value,
-					     int len);
-int igraph_i_pajek_add_numeric_vertex_attribute(const char *name, 
-						igraph_real_t value);
-int igraph_i_pajek_add_numeric_edge_attribute(const char *name, 
-					      igraph_real_t value);
-int igraph_i_pajek_add_numeric_attribute(igraph_trie_t *names,
-					 igraph_vector_ptr_t *attrs,
-					 long int count,
-					 const char *attrname,
-					 igraph_integer_t vid,
-					 igraph_real_t number);
-int igraph_i_pajek_add_string_attribute(igraph_trie_t *names,
-					igraph_vector_ptr_t *attrs,
-					long int count,
-					const char *attrname,
-					igraph_integer_t vid,
-					const char *str);
-void igraph_i_pajek_reset_scanner(void);
-extern igraph_vector_t *igraph_pajek_vector;
-extern igraph_bool_t igraph_pajek_directed;
-extern long int igraph_pajek_vcount;
-extern int igraph_pajek_mode;
-extern long int igraph_pajek_actfrom, igraph_pajek_actto;
-extern igraph_trie_t *igraph_i_pajek_vertex_attribute_names;
-extern igraph_vector_t *igraph_i_pajek_vertex_attribute_types;
-extern igraph_vector_ptr_t *igraph_i_pajek_vertex_attributes;
-extern igraph_trie_t *igraph_i_pajek_edge_attribute_names;
-extern igraph_vector_t *igraph_i_pajek_edge_attribute_types;
-extern igraph_vector_ptr_t *igraph_i_pajek_edge_attributes;
-extern igraph_real_t igraph_pajek_get_number(const char *str, long int len);
-extern long int igraph_i_pajek_actvertex;
-extern long int igraph_i_pajek_actedge;
-
-
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
-
-/* Enabling verbose error messages.  */
-#ifdef YYERROR_VERBOSE
-# undef YYERROR_VERBOSE
-# define YYERROR_VERBOSE 1
-#else
-# define YYERROR_VERBOSE 0
-#endif
-
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
-#endif
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 105 "foreign-pajek-parser.y"
 {
+
+/* Line 214 of yacc.c  */
+#line 105 "foreign-pajek-parser.y"
+
   long int intnum;
   double   realnum;  
   struct {
     char *str;
     int len;
   } string;  
-}
-/* Line 187 of yacc.c.  */
-#line 291 "foreign-pajek-parser.c"
-	YYSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 307 "foreign-pajek-parser.c"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 304 "foreign-pajek-parser.c"
+/* Line 264 of yacc.c  */
+#line 319 "foreign-pajek-parser.c"
 
 #ifdef short
 # undef short
@@ -375,14 +390,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -463,9 +478,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -499,12 +514,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -664,12 +679,12 @@ static const char *const yytname[] =
   "EP_C", "EP_S", "EP_A", "EP_W", "EP_H1", "EP_H2", "EP_A1", "EP_A2",
   "EP_K1", "EP_K2", "EP_AP", "EP_P", "EP_L", "EP_LP", "EP_LR", "EP_LPHI",
   "EP_LC", "EP_LA", "EP_SIZE", "EP_FOS", "$accept", "input", "nethead",
-  "vertices", "verticeshead", "vertdefs", "vertexline", "@1", "vertex",
-  "vertexid", "vertexcoords", "shape", "params", "param", "vpword", "@2",
-  "@3", "@4", "@5", "@6", "vpwordpar", "edgeblock", "arcs", "arcsdefs",
-  "arcsline", "@7", "arcfrom", "arcto", "edges", "edgesdefs", "edgesline",
-  "@8", "edgefrom", "edgeto", "weight", "edgeparams", "edgeparam",
-  "epword", "@9", "@10", "@11", "@12", "@13", "epwordpar", "arcslist",
+  "vertices", "verticeshead", "vertdefs", "vertexline", "$@1", "vertex",
+  "vertexid", "vertexcoords", "shape", "params", "param", "vpword", "$@2",
+  "$@3", "$@4", "$@5", "$@6", "vpwordpar", "edgeblock", "arcs", "arcsdefs",
+  "arcsline", "$@7", "arcfrom", "arcto", "edges", "edgesdefs", "edgesline",
+  "$@8", "edgefrom", "edgeto", "weight", "edgeparams", "edgeparam",
+  "epword", "$@9", "$@10", "$@11", "$@12", "$@13", "epwordpar", "arcslist",
   "arcslistlines", "arclistline", "arctolist", "arclistfrom", "arclistto",
   "edgeslist", "edgelistlines", "edgelistline", "edgetolist",
   "edgelistfrom", "edgelistto", "adjmatrix", "matrixline",
@@ -1079,17 +1094,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -1123,11 +1141,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1407,10 +1425,8 @@ yydestruct (yymsg, yytype, yyvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1426,11 +1442,10 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1438,9 +1453,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1464,14 +1479,39 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1479,51 +1519,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1553,7 +1570,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1561,7 +1577,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1584,9 +1599,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1597,7 +1611,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1607,6 +1620,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1615,16 +1631,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1656,20 +1672,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1709,6 +1721,8 @@ yyreduce:
   switch (yyn)
     {
         case 6:
+
+/* Line 1455 of yacc.c  */
 #line 185 "foreign-pajek-parser.y"
     {
   igraph_pajek_vcount=(yyvsp[(2) - (2)].intnum);
@@ -1716,21 +1730,29 @@ yyreduce:
     break;
 
   case 11:
+
+/* Line 1455 of yacc.c  */
 #line 193 "foreign-pajek-parser.y"
     { igraph_i_pajek_actvertex=(yyvsp[(1) - (1)].intnum); }
     break;
 
   case 12:
+
+/* Line 1455 of yacc.c  */
 #line 193 "foreign-pajek-parser.y"
     { }
     break;
 
   case 13:
+
+/* Line 1455 of yacc.c  */
 #line 196 "foreign-pajek-parser.y"
     { (yyval.intnum)=(yyvsp[(1) - (1)].intnum); igraph_pajek_mode=1; }
     break;
 
   case 14:
+
+/* Line 1455 of yacc.c  */
 #line 198 "foreign-pajek-parser.y"
     {
   igraph_i_pajek_add_string_vertex_attribute("id", (yyvsp[(1) - (1)].string).str, (yyvsp[(1) - (1)].string).len);
@@ -1738,6 +1760,8 @@ yyreduce:
     break;
 
   case 16:
+
+/* Line 1455 of yacc.c  */
 #line 203 "foreign-pajek-parser.y"
     { 
   igraph_i_pajek_add_numeric_vertex_attribute("x", (yyvsp[(1) - (2)].realnum));
@@ -1746,6 +1770,8 @@ yyreduce:
     break;
 
   case 17:
+
+/* Line 1455 of yacc.c  */
 #line 207 "foreign-pajek-parser.y"
     { 
   igraph_i_pajek_add_numeric_vertex_attribute("x", (yyvsp[(1) - (3)].realnum));
@@ -1755,6 +1781,8 @@ yyreduce:
     break;
 
   case 19:
+
+/* Line 1455 of yacc.c  */
 #line 213 "foreign-pajek-parser.y"
     { 
   igraph_i_pajek_add_string_vertex_attribute("shape", (yyvsp[(1) - (1)].string).str, (yyvsp[(1) - (1)].string).len);	      
@@ -1762,6 +1790,8 @@ yyreduce:
     break;
 
   case 23:
+
+/* Line 1455 of yacc.c  */
 #line 221 "foreign-pajek-parser.y"
     {
 	 igraph_i_pajek_add_numeric_vertex_attribute("xfact", (yyvsp[(2) - (2)].realnum));
@@ -1769,6 +1799,8 @@ yyreduce:
     break;
 
   case 24:
+
+/* Line 1455 of yacc.c  */
 #line 224 "foreign-pajek-parser.y"
     {
 	 igraph_i_pajek_add_numeric_vertex_attribute("yfact", (yyvsp[(2) - (2)].realnum));
@@ -1776,6 +1808,8 @@ yyreduce:
     break;
 
   case 25:
+
+/* Line 1455 of yacc.c  */
 #line 227 "foreign-pajek-parser.y"
     { /* RGB color */
          igraph_i_pajek_add_numeric_vertex_attribute("color-red", (yyvsp[(2) - (4)].realnum));
@@ -1785,6 +1819,8 @@ yyreduce:
     break;
 
   case 26:
+
+/* Line 1455 of yacc.c  */
 #line 232 "foreign-pajek-parser.y"
     {
          igraph_i_pajek_add_numeric_vertex_attribute("framecolor-red", (yyvsp[(2) - (4)].realnum));
@@ -1794,6 +1830,8 @@ yyreduce:
     break;
 
   case 27:
+
+/* Line 1455 of yacc.c  */
 #line 237 "foreign-pajek-parser.y"
     {
          igraph_i_pajek_add_numeric_vertex_attribute("labelcolor-red", (yyvsp[(2) - (4)].realnum));
@@ -1803,6 +1841,8 @@ yyreduce:
     break;
 
   case 28:
+
+/* Line 1455 of yacc.c  */
 #line 242 "foreign-pajek-parser.y"
     {
          igraph_i_pajek_add_numeric_vertex_attribute("labeldist", (yyvsp[(2) - (2)].realnum));
@@ -1810,6 +1850,8 @@ yyreduce:
     break;
 
   case 29:
+
+/* Line 1455 of yacc.c  */
 #line 245 "foreign-pajek-parser.y"
     {
          igraph_i_pajek_add_numeric_vertex_attribute("labeldegree2", (yyvsp[(2) - (2)].realnum));
@@ -1817,6 +1859,8 @@ yyreduce:
     break;
 
   case 30:
+
+/* Line 1455 of yacc.c  */
 #line 248 "foreign-pajek-parser.y"
     {
          igraph_i_pajek_add_numeric_vertex_attribute("framewidth", (yyvsp[(2) - (2)].realnum));
@@ -1824,6 +1868,8 @@ yyreduce:
     break;
 
   case 31:
+
+/* Line 1455 of yacc.c  */
 #line 251 "foreign-pajek-parser.y"
     {
          igraph_i_pajek_add_numeric_vertex_attribute("fontsize", (yyvsp[(2) - (2)].realnum));
@@ -1831,6 +1877,8 @@ yyreduce:
     break;
 
   case 32:
+
+/* Line 1455 of yacc.c  */
 #line 254 "foreign-pajek-parser.y"
     {       
          igraph_i_pajek_add_numeric_vertex_attribute("rotation", (yyvsp[(2) - (2)].realnum));
@@ -1838,6 +1886,8 @@ yyreduce:
     break;
 
   case 33:
+
+/* Line 1455 of yacc.c  */
 #line 257 "foreign-pajek-parser.y"
     {
          igraph_i_pajek_add_numeric_vertex_attribute("radius", (yyvsp[(2) - (2)].realnum));
@@ -1845,6 +1895,8 @@ yyreduce:
     break;
 
   case 34:
+
+/* Line 1455 of yacc.c  */
 #line 260 "foreign-pajek-parser.y"
     {
          igraph_i_pajek_add_numeric_vertex_attribute("diamondratio", (yyvsp[(2) - (2)].realnum));
@@ -1852,6 +1904,8 @@ yyreduce:
     break;
 
   case 35:
+
+/* Line 1455 of yacc.c  */
 #line 263 "foreign-pajek-parser.y"
     {
          igraph_i_pajek_add_numeric_vertex_attribute("labeldegree", (yyvsp[(2) - (2)].realnum));
@@ -1859,6 +1913,8 @@ yyreduce:
     break;
 
   case 36:
+
+/* Line 1455 of yacc.c  */
 #line 266 "foreign-pajek-parser.y"
     {
          igraph_i_pajek_add_numeric_vertex_attribute("vertexsize", (yyvsp[(2) - (2)].realnum));
@@ -1866,11 +1922,15 @@ yyreduce:
     break;
 
   case 37:
+
+/* Line 1455 of yacc.c  */
 #line 271 "foreign-pajek-parser.y"
     { igraph_pajek_mode=3; }
     break;
 
   case 38:
+
+/* Line 1455 of yacc.c  */
 #line 271 "foreign-pajek-parser.y"
     { 
          igraph_pajek_mode=1;
@@ -1879,11 +1939,15 @@ yyreduce:
     break;
 
   case 39:
+
+/* Line 1455 of yacc.c  */
 #line 275 "foreign-pajek-parser.y"
     { igraph_pajek_mode=3; }
     break;
 
   case 40:
+
+/* Line 1455 of yacc.c  */
 #line 275 "foreign-pajek-parser.y"
     {
          igraph_pajek_mode=1;
@@ -1892,11 +1956,15 @@ yyreduce:
     break;
 
   case 41:
+
+/* Line 1455 of yacc.c  */
 #line 279 "foreign-pajek-parser.y"
     { igraph_pajek_mode=3; }
     break;
 
   case 42:
+
+/* Line 1455 of yacc.c  */
 #line 279 "foreign-pajek-parser.y"
     {
          igraph_pajek_mode=1;
@@ -1905,11 +1973,15 @@ yyreduce:
     break;
 
   case 43:
+
+/* Line 1455 of yacc.c  */
 #line 283 "foreign-pajek-parser.y"
     { igraph_pajek_mode=3; }
     break;
 
   case 44:
+
+/* Line 1455 of yacc.c  */
 #line 283 "foreign-pajek-parser.y"
     {
          igraph_pajek_mode=1;
@@ -1919,11 +1991,15 @@ yyreduce:
     break;
 
   case 45:
+
+/* Line 1455 of yacc.c  */
 #line 288 "foreign-pajek-parser.y"
     { igraph_pajek_mode=3; }
     break;
 
   case 46:
+
+/* Line 1455 of yacc.c  */
 #line 288 "foreign-pajek-parser.y"
     {
          igraph_pajek_mode=1;
@@ -1933,22 +2009,30 @@ yyreduce:
     break;
 
   case 47:
+
+/* Line 1455 of yacc.c  */
 #line 295 "foreign-pajek-parser.y"
     { (yyval.string)=(yyvsp[(1) - (1)].string); }
     break;
 
   case 54:
+
+/* Line 1455 of yacc.c  */
 #line 299 "foreign-pajek-parser.y"
     { igraph_pajek_directed=1; }
     break;
 
   case 58:
+
+/* Line 1455 of yacc.c  */
 #line 304 "foreign-pajek-parser.y"
     { igraph_i_pajek_actedge++;
 	                  igraph_pajek_mode=2; }
     break;
 
   case 59:
+
+/* Line 1455 of yacc.c  */
 #line 305 "foreign-pajek-parser.y"
     { 
   igraph_vector_push_back(igraph_pajek_vector, (yyvsp[(1) - (6)].intnum)-1);
@@ -1956,17 +2040,23 @@ yyreduce:
     break;
 
   case 62:
+
+/* Line 1455 of yacc.c  */
 #line 314 "foreign-pajek-parser.y"
     { igraph_pajek_directed=0; }
     break;
 
   case 66:
+
+/* Line 1455 of yacc.c  */
 #line 319 "foreign-pajek-parser.y"
     { igraph_i_pajek_actedge++; 
 	                    igraph_pajek_mode=2; }
     break;
 
   case 67:
+
+/* Line 1455 of yacc.c  */
 #line 320 "foreign-pajek-parser.y"
     { 
   igraph_vector_push_back(igraph_pajek_vector, (yyvsp[(1) - (6)].intnum)-1);
@@ -1974,6 +2064,8 @@ yyreduce:
     break;
 
   case 71:
+
+/* Line 1455 of yacc.c  */
 #line 329 "foreign-pajek-parser.y"
     {
   igraph_i_pajek_add_numeric_edge_attribute("weight", (yyvsp[(1) - (1)].realnum));
@@ -1981,6 +2073,8 @@ yyreduce:
     break;
 
   case 75:
+
+/* Line 1455 of yacc.c  */
 #line 337 "foreign-pajek-parser.y"
     {
        igraph_i_pajek_add_numeric_edge_attribute("color-red", (yyvsp[(2) - (4)].realnum));
@@ -1990,6 +2084,8 @@ yyreduce:
     break;
 
   case 76:
+
+/* Line 1455 of yacc.c  */
 #line 342 "foreign-pajek-parser.y"
     { 
        igraph_i_pajek_add_numeric_edge_attribute("arrowsize", (yyvsp[(2) - (2)].realnum));
@@ -1997,6 +2093,8 @@ yyreduce:
     break;
 
   case 77:
+
+/* Line 1455 of yacc.c  */
 #line 345 "foreign-pajek-parser.y"
     {
        igraph_i_pajek_add_numeric_edge_attribute("edgewidth", (yyvsp[(2) - (2)].realnum));
@@ -2004,6 +2102,8 @@ yyreduce:
     break;
 
   case 78:
+
+/* Line 1455 of yacc.c  */
 #line 348 "foreign-pajek-parser.y"
     {
        igraph_i_pajek_add_numeric_edge_attribute("hook1", (yyvsp[(2) - (2)].realnum));
@@ -2011,6 +2111,8 @@ yyreduce:
     break;
 
   case 79:
+
+/* Line 1455 of yacc.c  */
 #line 351 "foreign-pajek-parser.y"
     {
        igraph_i_pajek_add_numeric_edge_attribute("hook2", (yyvsp[(2) - (2)].realnum));
@@ -2018,6 +2120,8 @@ yyreduce:
     break;
 
   case 80:
+
+/* Line 1455 of yacc.c  */
 #line 354 "foreign-pajek-parser.y"
     {
        igraph_i_pajek_add_numeric_edge_attribute("angle1", (yyvsp[(2) - (2)].realnum));
@@ -2025,6 +2129,8 @@ yyreduce:
     break;
 
   case 81:
+
+/* Line 1455 of yacc.c  */
 #line 357 "foreign-pajek-parser.y"
     {
        igraph_i_pajek_add_numeric_edge_attribute("angle2", (yyvsp[(2) - (2)].realnum));
@@ -2032,6 +2138,8 @@ yyreduce:
     break;
 
   case 82:
+
+/* Line 1455 of yacc.c  */
 #line 360 "foreign-pajek-parser.y"
     {
        igraph_i_pajek_add_numeric_edge_attribute("velocity1", (yyvsp[(2) - (2)].realnum));
@@ -2039,6 +2147,8 @@ yyreduce:
     break;
 
   case 83:
+
+/* Line 1455 of yacc.c  */
 #line 363 "foreign-pajek-parser.y"
     {
        igraph_i_pajek_add_numeric_edge_attribute("velocity2", (yyvsp[(2) - (2)].realnum));
@@ -2046,6 +2156,8 @@ yyreduce:
     break;
 
   case 84:
+
+/* Line 1455 of yacc.c  */
 #line 366 "foreign-pajek-parser.y"
     {
        igraph_i_pajek_add_numeric_edge_attribute("arrowpos", (yyvsp[(2) - (2)].realnum));
@@ -2053,6 +2165,8 @@ yyreduce:
     break;
 
   case 85:
+
+/* Line 1455 of yacc.c  */
 #line 369 "foreign-pajek-parser.y"
     {
        igraph_i_pajek_add_numeric_edge_attribute("labelpos", (yyvsp[(2) - (2)].realnum));
@@ -2060,6 +2174,8 @@ yyreduce:
     break;
 
   case 86:
+
+/* Line 1455 of yacc.c  */
 #line 372 "foreign-pajek-parser.y"
     {
        igraph_i_pajek_add_numeric_edge_attribute("labelangle", (yyvsp[(2) - (2)].realnum));
@@ -2067,6 +2183,8 @@ yyreduce:
     break;
 
   case 87:
+
+/* Line 1455 of yacc.c  */
 #line 375 "foreign-pajek-parser.y"
     {
        igraph_i_pajek_add_numeric_edge_attribute("labelangle2", (yyvsp[(2) - (2)].realnum));
@@ -2074,6 +2192,8 @@ yyreduce:
     break;
 
   case 88:
+
+/* Line 1455 of yacc.c  */
 #line 378 "foreign-pajek-parser.y"
     {
        igraph_i_pajek_add_numeric_edge_attribute("labeldegree", (yyvsp[(2) - (2)].realnum));
@@ -2081,6 +2201,8 @@ yyreduce:
     break;
 
   case 89:
+
+/* Line 1455 of yacc.c  */
 #line 381 "foreign-pajek-parser.y"
     {		/* what is this??? */
        igraph_i_pajek_add_numeric_edge_attribute("arrowsize", (yyvsp[(2) - (2)].realnum));
@@ -2088,6 +2210,8 @@ yyreduce:
     break;
 
   case 90:
+
+/* Line 1455 of yacc.c  */
 #line 384 "foreign-pajek-parser.y"
     {
        igraph_i_pajek_add_numeric_edge_attribute("fontsize", (yyvsp[(2) - (2)].realnum));
@@ -2095,11 +2219,15 @@ yyreduce:
     break;
 
   case 91:
+
+/* Line 1455 of yacc.c  */
 #line 389 "foreign-pajek-parser.y"
     { igraph_pajek_mode=4; }
     break;
 
   case 92:
+
+/* Line 1455 of yacc.c  */
 #line 389 "foreign-pajek-parser.y"
     {
       igraph_pajek_mode=2;
@@ -2108,11 +2236,15 @@ yyreduce:
     break;
 
   case 93:
+
+/* Line 1455 of yacc.c  */
 #line 393 "foreign-pajek-parser.y"
     { igraph_pajek_mode=4; }
     break;
 
   case 94:
+
+/* Line 1455 of yacc.c  */
 #line 393 "foreign-pajek-parser.y"
     {
       igraph_pajek_mode=2;
@@ -2121,11 +2253,15 @@ yyreduce:
     break;
 
   case 95:
+
+/* Line 1455 of yacc.c  */
 #line 397 "foreign-pajek-parser.y"
     { igraph_pajek_mode=4; }
     break;
 
   case 96:
+
+/* Line 1455 of yacc.c  */
 #line 397 "foreign-pajek-parser.y"
     {
       igraph_pajek_mode=2;
@@ -2134,11 +2270,15 @@ yyreduce:
     break;
 
   case 97:
+
+/* Line 1455 of yacc.c  */
 #line 401 "foreign-pajek-parser.y"
     { igraph_pajek_mode=4; }
     break;
 
   case 98:
+
+/* Line 1455 of yacc.c  */
 #line 401 "foreign-pajek-parser.y"
     {
       igraph_pajek_mode=2;
@@ -2147,11 +2287,15 @@ yyreduce:
     break;
 
   case 99:
+
+/* Line 1455 of yacc.c  */
 #line 405 "foreign-pajek-parser.y"
     { igraph_pajek_mode=4; }
     break;
 
   case 100:
+
+/* Line 1455 of yacc.c  */
 #line 405 "foreign-pajek-parser.y"
     {
       igraph_pajek_mode=2;
@@ -2160,21 +2304,29 @@ yyreduce:
     break;
 
   case 101:
+
+/* Line 1455 of yacc.c  */
 #line 411 "foreign-pajek-parser.y"
     { igraph_pajek_mode=2; (yyval.string)=(yyvsp[(1) - (1)].string); }
     break;
 
   case 102:
+
+/* Line 1455 of yacc.c  */
 #line 413 "foreign-pajek-parser.y"
     { igraph_pajek_directed=1; }
     break;
 
   case 109:
+
+/* Line 1455 of yacc.c  */
 #line 421 "foreign-pajek-parser.y"
     { igraph_pajek_mode=0; igraph_pajek_actfrom=fabs((yyvsp[(1) - (1)].intnum))-1; }
     break;
 
   case 110:
+
+/* Line 1455 of yacc.c  */
 #line 423 "foreign-pajek-parser.y"
     { 
   igraph_vector_push_back(igraph_pajek_vector, igraph_pajek_actfrom); 
@@ -2183,16 +2335,22 @@ yyreduce:
     break;
 
   case 111:
+
+/* Line 1455 of yacc.c  */
 #line 428 "foreign-pajek-parser.y"
     { igraph_pajek_directed=0; }
     break;
 
   case 118:
+
+/* Line 1455 of yacc.c  */
 #line 436 "foreign-pajek-parser.y"
     { igraph_pajek_mode=0; igraph_pajek_actfrom=fabs((yyvsp[(1) - (1)].intnum))-1; }
     break;
 
   case 119:
+
+/* Line 1455 of yacc.c  */
 #line 438 "foreign-pajek-parser.y"
     { 
   igraph_vector_push_back(igraph_pajek_vector, igraph_pajek_actfrom); 
@@ -2201,16 +2359,22 @@ yyreduce:
     break;
 
   case 121:
+
+/* Line 1455 of yacc.c  */
 #line 447 "foreign-pajek-parser.y"
     { igraph_pajek_actfrom=0; igraph_pajek_actto=0; }
     break;
 
   case 124:
+
+/* Line 1455 of yacc.c  */
 #line 451 "foreign-pajek-parser.y"
     { igraph_pajek_actfrom++; igraph_pajek_actto=0; }
     break;
 
   case 127:
+
+/* Line 1455 of yacc.c  */
 #line 455 "foreign-pajek-parser.y"
     {
   if ((yyvsp[(1) - (1)].intnum)>0) { 
@@ -2222,35 +2386,46 @@ yyreduce:
     break;
 
   case 128:
+
+/* Line 1455 of yacc.c  */
 #line 465 "foreign-pajek-parser.y"
     { (yyval.intnum)=igraph_pajek_get_number(igraph_pajek_yytext,
 					  igraph_pajek_yyleng); }
     break;
 
   case 129:
+
+/* Line 1455 of yacc.c  */
 #line 468 "foreign-pajek-parser.y"
     { (yyval.realnum)=igraph_pajek_get_number(igraph_pajek_yytext,
 					  igraph_pajek_yyleng); }
     break;
 
   case 132:
+
+/* Line 1455 of yacc.c  */
 #line 473 "foreign-pajek-parser.y"
     { (yyval.string).str=igraph_pajek_yytext; (yyval.string).len=igraph_pajek_yyleng; }
     break;
 
   case 133:
+
+/* Line 1455 of yacc.c  */
 #line 474 "foreign-pajek-parser.y"
     { (yyval.string).str=igraph_pajek_yytext; (yyval.string).len=igraph_pajek_yyleng; }
     break;
 
   case 134:
+
+/* Line 1455 of yacc.c  */
 #line 475 "foreign-pajek-parser.y"
     { (yyval.string).str=igraph_pajek_yytext+1; (yyval.string).len=igraph_pajek_yyleng-2; }
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 2254 "foreign-pajek-parser.c"
+
+/* Line 1455 of yacc.c  */
+#line 2429 "foreign-pajek-parser.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2261,7 +2436,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -2326,7 +2500,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -2343,7 +2517,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -2400,9 +2574,6 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -2427,7 +2598,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -2438,7 +2609,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -2464,6 +2635,8 @@ yyreturn:
 }
 
 
+
+/* Line 1675 of yacc.c  */
 #line 477 "foreign-pajek-parser.y"
 
 
